//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "VKEventMessenger.hh"
#include "VKEventAction.hh"

#include "G4UIcmdWithABool.hh"
#include "G4UIcmdWithAnInteger.hh"


VKEventMessenger::VKEventMessenger(VKEventAction* event)
 : fVKEvent(event)
{
  fSaveThresholdCmd = new G4UIcmdWithAnInteger("/VK/saveThreshold",this);
  fSaveThresholdCmd -> SetGuidance("Set the photon count threshold for saving the random number seed");
  fSaveThresholdCmd -> SetParameterName("photons", true);
  fSaveThresholdCmd -> SetDefaultValue(4500);
  fSaveThresholdCmd -> AvailableForStates(G4State_PreInit, G4State_Idle);

  fVerboseCmd = new G4UIcmdWithAnInteger("/VK/eventVerbose",this);
  fVerboseCmd -> SetGuidance("Set the verbosity of event data.");
  fVerboseCmd -> SetParameterName("verbose",true);
  fVerboseCmd -> SetDefaultValue(1);

  fSiPMThresholdCmd = new G4UIcmdWithAnInteger("/VK/SiPMThreshold",this);
  fSiPMThresholdCmd -> SetGuidance("Set the SiPM threshold (in # of photons)");

  fForceDrawPhotonsCmd = new G4UIcmdWithABool("/VK/forceDrawPhotons",this);
  fForceDrawPhotonsCmd -> SetGuidance("Force drawing of photons.");
  fForceDrawPhotonsCmd -> SetGuidance("(Higher priority than /VK/forceDrawNoPhotons)");

  fForceDrawNoPhotonsCmd = new G4UIcmdWithABool("/VK/forceDrawNoPhotons",this);
  fForceDrawNoPhotonsCmd -> SetGuidance("Force no drawing of photons.");
  fForceDrawNoPhotonsCmd -> SetGuidance("(Lower priority than /VK/forceDrawPhotons)");
}


VKEventMessenger::~VKEventMessenger(){
  delete fSaveThresholdCmd;
  delete fVerboseCmd;
  delete fSiPMThresholdCmd;
  delete fForceDrawPhotonsCmd;
  delete fForceDrawNoPhotonsCmd;
}


void VKEventMessenger::SetNewValue(G4UIcommand* command, G4String newValue){
  if (command == fSaveThresholdCmd) {
    fVKEvent->SetSaveThreshold(fSaveThresholdCmd->GetNewIntValue(newValue));
  }
  else if (command == fVerboseCmd) {
    fVKEvent->SetEventVerbose(fVerboseCmd->GetNewIntValue(newValue));
  }
  else if (command == fSiPMThresholdCmd) {
    fVKEvent->SetSiPMThreshold(fSiPMThresholdCmd->GetNewIntValue(newValue));
  }
  else if (command == fForceDrawPhotonsCmd) {
    fVKEvent->SetForceDrawPhotons(fForceDrawPhotonsCmd->GetNewBoolValue(newValue));
  }
  else if (command == fForceDrawNoPhotonsCmd) {
    fVKEvent->SetForceDrawNoPhotons(fForceDrawNoPhotonsCmd->GetNewBoolValue(newValue));
  }
}
